#!/bin/bash

#export IGDATA=/home/david/tmp/ncbi-igblast-1.0.0;

clonalType=${@:(-3):1}
html=${@:(-2):1}
imageDir=${@:(-1):1}
dataCount=`expr $# - 3`
inputData=${@:(1):dataCount}
dir="$(cd "$(dirname "$0")" && pwd)"
array=("$@")
echo "<html><h3>Progress</h3><table><tr><td>info</td></tr>" > $html
echo "<tr><td>-----------------------------------</td></tr>" >> $html

id=${inputData[0]}
forwardSlash="/"
mergerInput=()
count=0
for current in $inputData; do
    if [[ "$current" != *"$forwardSlash"* ]]; then
        id=$current
        count=0
        mergerInput+=($id)
        continue
    fi
    fileName=$(basename $current)
    convertedFileName="${fileName%.*}"
    convertedFileName="$PWD/$convertedFileName.converted"
	bash $dir/imgtconvert.sh $current $id $count $convertedFileName
	mergerInput+=($convertedFileName)
	count=$((count+1))
done



echo "<tr><td>-----------------------------------</td></tr>" >> $html
echo "<tr><td>merging</td></tr>" >> $html

python $dir/igblastmerge.py ${mergerInput[*]}  --output $PWD/merged.txt

echo "<tr><td>done</td></tr>" >> $html
echo "<tr><td>-----------------------------------</td></tr>" >> $html
echo "<tr><td>plotting</td></tr>" >> $html


inputFile=$PWD/merged.txt
outputDir=$imageDir
outputFile=$outputDir/index.html
mkdir $outputDir
Rscript --verbose $dir/RScript.r $inputFile $outputDir $outputDir $clonalType 2>&1
cp $dir/tabber.js $outputDir
cp $dir/style.css $outputDir
cp $dir/script.js $outputDir
echo "<html><center><h1><a href='index.html'>Click here for the results</a></h1>Tip: Open it in a new tab (middle mouse button or right mouse button -> 'open in new tab' on the link above)</center></html>" > $html
echo "<html><script type='text/javascript' src='tabber.js'></script><script type='text/javascript' src='script.js'></script><link rel='stylesheet' type='text/css' href='style.css'><div class='tabber'><div class='tabbertab' title='Gene frequencies'>" >> $outputFile
echo "<img src='VPlot.png'/>" >> $outputFile
echo "<img src='DPlot.png'/>" >> $outputFile
echo "<img src='JPlot.png'/></div>" >> $outputFile

samples=`cat $outputDir/samples.txt`
count=1
echo "<div class='tabbertab' title='Heatmaps'><div class='tabber'>" >> $outputFile
for sample in $samples; do
	echo "<div class='tabbertab' title='$sample'><table border='1'><tr>" >> $outputFile
	
	mv "$outputDir/HeatmapVD_$sample.png" "$outputDir/VD_$sample.png"
	echo "<td><img src='VD_$sample.png'/></td>" >> $outputFile
	mv "$outputDir/HeatmapVJ_$sample.png" "$outputDir/VJ_$sample.png"
	echo "<td><img src='VJ_$sample.png'/></td>" >> $outputFile
	mv "$outputDir/HeatmapDJ_$sample.png" "$outputDir/DJ_$sample.png"
	echo "<td><img src='DJ_$sample.png'/></td></tr></table></div>" >> $outputFile
	count=$((count+1))
done
echo "</div></div>" >> $outputFile


hasReplicateColumn="$(if head -n 1 $inputFile | grep -q 'Replicate'; then echo 'Yes'; else echo 'No'; fi)"
echo "$hasReplicateColumn"
#if its a 'new' merged file with replicate info
if [[ "$hasReplicateColumn" == "Yes" ]] ; then
	echo "<div class='tabbertab' title='Clonality'><div class='tabber'>" >> $outputFile
	for sample in $samples; do
		clonalityScore="$(cat $outputDir/ClonalityScore_$sample.csv)"
		echo "<div class='tabbertab' title='$sample'><table border='1'>" >> $outputFile
		echo "<tr><td colspan='4'>Clonality Score: $clonalityScore</td></tr>" >> $outputFile

		#replicate,reads,squared
		echo "<tr><td>Replicate ID</td><td>Number of Reads</td><td>Reads Squared</td><td></td></tr>" >> $outputFile
		while IFS=, read replicate reads squared
		do
			
			echo "<tr><td>$replicate</td><td>$reads</td><td>$squared</td><td></td></tr>" >> $outputFile
		done < $outputDir/ReplicateReads_$sample.csv
		
		#sum of reads and reads squared
		while IFS=, read readsSum squaredSum
			do
				echo "<tr><td>Sum</td><td>$readsSum</td><td>$squaredSum</td></tr>" >> $outputFile
		done < $outputDir/ReplicateSumReads_$sample.csv
		
		#overview
		echo "<tr><td>Coincidence Type</td><td>Raw Coincidence Freq</td><td>Coincidence Weight</td><td>Coincidences, Weighted</td></tr>" >> $outputFile
		while IFS=, read type count weight weightedCount
		do
			echo "<tr><td>$type</td><td>$count</td><td>$weight</td><td>$weightedCount</td></tr>" >> $outputFile
		done < $outputDir/ClonalityOverView_$sample.csv
		echo "</table></div>" >> $outputFile
	done
	echo "</div></div>" >> $outputFile
fi

if [[ "$hasReplicateColumn" == "Yes" ]] ; then
	echo "<div class='tabbertab' title='Junction Analysis'><table border='1'><tr><th>Sample</th><th>unique</th><th>VH.DEL</th><th>P1</th><th>N1</th><th>P2</th><th>DEL.DH</th><th>DH.DEL</th><th>P3</th><th>N2</th><th>P4</th><th>DEL.JH</th><th>Total.Del</th><th>Total.N</th><th>Total.P</th></tr>" >> $outputFile
	while IFS=, read Sample unique VHDEL P1 N1 P2 DELDH DHDEL P3 N2 P4 DELJH TotalDel TotalN TotalP
	do
		echo "<tr><td>$Sample</td><td>$unique</td><td>$VHDEL</td><td>$P1</td><td>$N1</td><td>$P2</td><td>$DELDH</td><td>$DHDEL</td><td>$P3</td><td>$N2</td><td>$P4</td><td>$DELJH</td><td>$TotalDel</td><td>$TotalN</td><td>$TotalP</td></tr>" >> $outputFile
	done < $outputDir/junctionAnalysis.csv
	echo "</table></div>" >> $outputFile
fi

echo "<div class='tabbertab' title='Comparison'><table border='1'><tr><th>ID</th><th>Include</th></tr>" >> $outputFile
for sample in $samples; do
	echo "<tr><td>$sample</td><td><input type='checkbox' onchange=\"javascript:compareAdd('$sample')\" id='compare_checkbox_$sample'/></td></tr>" >> $outputFile
done
echo "</table><div name='comparisonarea'>" >> $outputFile
echo "<table><tr id='comparison_table_vd'></tr></table>" >> $outputFile
echo "<table><tr id='comparison_table_vj'></tr></table>" >> $outputFile
echo "<table><tr id='comparison_table_dj'></tr></table>" >> $outputFile
echo "</div></div>" >> $outputFile

echo "<div class='tabbertab' title='Downloads'>" >> $outputFile
echo "<table border='1'>" >> $outputFile
echo "<tr><th>Description</th><th>Link</th></tr>" >> $outputFile
echo "<tr><td>The dataset used to generate the frequency graphs and the heatmaps (Unique based on clonaltype, $clonalType)</td><td><a href='allUnique.tsv'>Download</a></td></tr>" >> $outputFile
echo "<tr><td>The dataset used to calculate clonality score (Unique based on clonaltype, $clonalType)</td><td><a href='clonalityComplete.tsv'>Download</a></td></tr>" >> $outputFile
echo "</table>" >> $outputFile
echo "</div>" >> $outputFile
